/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.governance.context.transaction;

import org.apache.shardingsphere.governance.core.registry.config.event.datasource.DataSourceChangeCompletedEvent;
import org.apache.shardingsphere.transaction.ShardingTransactionManagerEngine;
import org.apache.shardingsphere.transaction.context.TransactionContexts;
import org.apache.shardingsphere.transaction.core.XATransactionManagerType;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

import java.util.HashMap;
import java.util.Map;

import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.assertThat;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public final class GovernanceTransactionContextsTest {
    
    @Mock
    private TransactionContexts transactionContexts;
    
    @Mock
    private ShardingTransactionManagerEngine engine;
    
    @Mock
    private Map<String, ShardingTransactionManagerEngine> engineMap;
    
    @Mock
    private DataSourceChangeCompletedEvent event;
    
    @Test
    public void assertNewInstance() {
        when(transactionContexts.getDefaultTransactionManagerEngine()).thenReturn(engine);
        Map<String, ShardingTransactionManagerEngine> engines = new HashMap<>(1, 1);
        engines.put("name", engine);
        when(transactionContexts.getEngines()).thenReturn(engines);
        GovernanceTransactionContexts actual = new GovernanceTransactionContexts(transactionContexts, XATransactionManagerType.ATOMIKOS.getType());
        assertThat(actual.getEngines(), is(engines));
        assertThat(actual.getDefaultTransactionManagerEngine(), is(engine));
    }
    
    @Test
    public void assertClose() throws Exception {
        GovernanceTransactionContexts actual = new GovernanceTransactionContexts(transactionContexts, XATransactionManagerType.ATOMIKOS.getType());
        actual.close();
        verify(transactionContexts).close();
    }
    
    @Test
    public void assertRenew() throws Exception {
        when(event.getSchemaName()).thenReturn("name");
        when(transactionContexts.getEngines()).thenReturn(engineMap);
        when(engineMap.remove(eq("name"))).thenReturn(engine);
        GovernanceTransactionContexts actual = new GovernanceTransactionContexts(transactionContexts, XATransactionManagerType.ATOMIKOS.getType());
        actual.renew(event);
        verify(engine).close();
        verify(engineMap).put(eq("name"), any(ShardingTransactionManagerEngine.class));
    }
}
